Crate to_be

Crate to_be 

Enums

Terms
Directs custom truthyness behaviour.

Traits

Truthy
Trait that provides truthy attributes for an implementing type.

Functions

stock_term_strings
Obtain the stock term strings of the library.
string_is_falsey
Indicates that the given string, when trimmed, is deemed as “falsey”.
string_is_truey
Indicates that the given string, when trimmed, is deemed as “truey”.
string_is_truthy
Indicates whether the given string is “truthy” and, if so, whether it is “truey” or “falsey”.
string_is_truthy_with
Indicates whether the instance can be classed as “truthy” when evaluated against the given terms strings.